@@ -100,11 +100,11 @@ void KExifEntry::readEntry()
     mDescription = QString::fromUtf8(exif_tag_get_description(mExifEntry->tag));
 
 #ifdef HAVE_EXIF06
-    char val[1024];
-    exif_entry_get_value(mExifEntry, val, 1023);
+    QCString cstr(1024);
+    exif_entry_get_value(mExifEntry, cstr.data(), cstr.size()-1);
     // just in case we don't get a null-terminated string
-    val[1024] = '\0'; 
-    mValue = QString::fromUtf8((const char*)&val);
+    cstr[cstr.size()-1] = '\0';
+    mValue = QString::fromLatin1(cstr.data());
 #else
     mValue = QString::fromUtf8(exif_entry_get_value(mExifEntry));
 #endif
